@@ -8,9 +8,9 @@ from datasette.utils import (
     value_as_boolean,
     ValueAsBooleanError,
 )
-from subprocess import run
 import click
 from click.types import CompositeParamType
+from subprocess import run, CalledProcessError
 import json
 import os
 import pathlib
@@ -286,7 +286,7 @@ def _publish_vercel(
             click.echo("    vercel --prod".format(generate_dir), err=True)
         else:
             # Run the deploy with Vercel
-            cmd = ["vercel", "--confirm", "--no-clipboard"]
+            cmd = ["vercel", "--confirm"]
             if debug:
                 cmd.append("--debug")
             if not no_prod:
@@ -299,7 +299,10 @@ def _publish_vercel(
                 cmd.extend(["--scope", scope])
             # Add the secret
             cmd.extend(["--env", "DATASETTE_SECRET={}".format(secret)])
-            run(cmd)
+            try:
+                run(cmd, check=True)
+            except CalledProcessError as ex:
+                raise click.ClickException(str(ex))
 
 
 @hookimpl
